@@ -428,7 +428,7 @@ class BaseMeasureCompiler(object):
                     else:
                         measure.order = measure_type.order
 
-                    measure.value = value
+                    measure.value = measure_type.sign() * value
                     self.session.merge(measure)
                     grid_item.set_total_type(measure)
 
